@import url('default.css');
body {
    font: 100% Arial, FreeSans, sans-serif;
    background: White;
    color: Black;
}

div.body h1,
div.body h2,
div.body h3,
div.body h4,
div.body h5,
div.body h6 {
    color: Black;
    background-color: White;
    font-weight: bold;
    line-height: 125%;
    border: none;
    font: "Helvetica Neue",Arial,FreeSans,sans-serif;
}


div.document {
    background-color: White;
}

div.sphinxsidebar {
    background-color: #f6f6f6;
    border: 1px solid #eeeeee;
}

div.sphinxsidebar h3 {
    margin-left: -11px;
    margin-right: -6px;
    line-height: 1.5em;
}

div.sphinxsidebar h3,
div.sphinxsidebar h3 a {
    background-color: #76ad17;
    color: White;
    padding: 0 0.5em;
}

div.sphinxsidebar h3 a:hover {
    color: White;
}

div.sphinxsidebar h4,
div.sphinxsidebar h4 a {
    color: #205c90;
}

div.sphinxsidebar a,
div.sphinxsidebar p {
    color: #205c90;
}

div.related {
    background-color: #329fd7;
}

div.related a:hover {
    color: Black;
}

a:link, a:visited {
    color: #205c90;
    text-decoration: none;
}

a:link:hover,
a:visited:hover {
    color: #75ad0a;
}

