/* @override http://admin.euphorie.hosting.simplon.biz/++resource++NuPlone.style/main/base.css */

/* This CSS is written by Cornae. www.cornae.com */

/* Colour scheme

Orange warnings/accents:	ff8100 / white
Red for system errors:		red / white
Yellow for notes:			fdfdc8 / 6f5a44
Green for success:			b4ff8e / 405f31

*/

/* @group Sortable lists */

ol.sortable {
	position: relative;
}

ol.sortable li {
	cursor: move;
}

ol.sortable li:hover {
	border: solid silver 1px;
	-webkit-border-radius: 5px;
	-moz-border-radius: 5px;
	-o-border-radius: 5px;
	border-radius: 5px;
	padding-left: 47px;
	margin: -3px -8px;
	background: rgba(0,0,0,0.05) url(dragHandle.png) no-repeat 498px center;
	padding-top: 2px;
	padding-bottom: 2px;
}

ol.sortable li:hover:active {
	-webkit-box-shadow: inset 0 0 10px rgba(0,0,0,0.2);
	-moz-box-shadow: inset 0 0 10px rgba(0,0,0,0.2);
	-o-box-shadow: inset 0 0 10px rgba(0,0,0,0.2);
	box-shadow: inset 0 0 10px rgba(0,0,0,0.2);
}

ol.sortable:after {
	content: "Change order of items by dragging the handle";
	background-color: #fdfdc8;
	color: #6f5a44;
	border: 1px solid #d3d4a7;
	padding: 4px 10px;
	float: right;
	width: 186px;
	position: absolute;
	z-index: 2;
	display: none;
	top: 0;
	right: 0;
	margin-right: -228px;
	-webkit-box-shadow: 0 2px 10px rgba(0,0,0,0.25);
	-moz-box-shadow: 0 2px 10px rgba(0,0,0,0.25);
	box-shadow: 0 2px 10px rgba(0,0,0,0.25);
}

ol.sortable:hover:after {
	display: block;
}



/* @end */

/* @group Toggle */

span.toggle {
	width: 16px;
	height: 16px;
	text-indent: -1000px;
	display: inline-block;
	overflow: hidden;
	background-image: url(twistie.png);
	-webkit-transition: all 0.5s;
	-moz-transition: all 0.5s;
	-o-transition: all 0.5s;
	transition: all 0.5s;
	-webkit-user-select: none;
	-moz-user-select: none;
	-o-user-select: none;
	user-select: none;
}

span.toggle.open {
	-webkit-transform: rotate(90deg);
	-moz-transform: rotate(90deg);
	-o-transform: rotate(90deg);
	transform: rotate(90deg);
}



/* @end */

/* @group Function list */

ul.functions {
	margin-left: 0;
	list-style-type: none;
	padding: 0;
	border-top: 1px solid #ebebeb;
}

ul.functions li {
	border-bottom: 1px solid #ebebeb;
}

ul.functions .function {
	padding-left: 15px;
	font-size: 10px;
	display: inline-block;
}



/* @end */

/* @group TinyMCE */

body.edit {
	position: relative;
	top: 40px;
}

#tinyControls {
	position: fixed !important;
	width: 100%;
	z-index: 10000 !important;
	overflow: hidden;
	height: 40px;
	border-style: none;
	border-bottom: 1px solid #797979;
}



/* @end */

/* @group Accordion */

dl.accordion {
	float: left;
	width: 100%;
	margin: 0 0 20px;
	padding: 0;
}

dl.accordion dt {
	margin: 0;
	float: left;
	width: 488px;
	-webkit-transition: all 0.5s;
}

dl.accordion dt.ui-state-active {
	background-image: none;
	color: black;
	font-weight: bold;
	text-shadow: none;
	-webkit-box-shadow: 0 2px 5px rgba(0,0,0,0);
	-moz-box-shadow: 0 2px 5px rgba(0,0,0,0);
	box-shadow: 0 2px 5px rgba(0,0,0,0);
	background-color: transparent;
	border-color: rgba(255,254,255,0);
	outline: none;
	padding-left: 20px;
	width: 478px;
}

dl.accordion dd {
	float: left;
	padding: 0 !important;
	position: relative;
	width: 100%;
	margin: 0;
}

dl.accordion .colborder hr,dl.accordion .colborder p.legend {
	display: none;
}

dl.accordion dt button {
	float: right;
	position: relative;
	top: 0;
	opacity: 0;
	-webkit-transform: 0.4s opacity;
	margin-bottom: -8px;
	margin-top: -1px;
}

dl.accordion dt:hover button {
	opacity: 1;
}

dl.accordion dt.ui-state-active button {
	opacity: 1;
}

dl.accordion dd dfn.infoPanel {
	position: absolute;
	top: -24px;
	left: 0;
}



/* @end */

/* @group Rich text */

.empty div.input.rich {
	border: 1px solid #dedede;
	margin-bottom: 1px;
}

* {

}

div.z3cFieldContainer {
    clear: both;
}

.richInput.empty div.input.rich {
	min-height: 40px;
}

.comprehensive div.input.rich {
}

div.input.rich:hover {
	background-color: #fdfdc8;
}

div.input.rich:focus,
.richInput.empty div.input.rich:focus {
	outline: none;
	padding: 0 5px;
	margin: -2px -7px;
	border: 2px dashed #aed8ff;
	background-color: transparent;
}

.comprehensive div.input.rich:focus {
	margin-top: -2px;
	margin-left: -7px;
	margin-bottom: -1px;
}

.comprehensive.empty div.input.rich:focus {
	margin-bottom: 1px;
}

.comprehensive .superImpose {
	position: absolute !important;
	left: 35%;
	padding-left: 6px !important;
	padding-top: 3px !important;
}



/* @end */

/* @group Animations */

@-webkit-keyframes pop {
  0%   { -webkit-transform: scale(1)}
  70% { -webkit-transform: scale(1.1)}
  100% { -webkit-transform: scale(1)}
}



/* @end */

/* @group Blueprint */

/* @group Grid */
div.span-1, div.span-2, div.span-3, div.span-4, div.span-5,
div.span-6, div.span-7, div.span-8, div.span-9, div.span-10,
div.span-11, div.span-12, div.span-13, div.span-14, div.span-15,
div.span-16, div.span-17, div.span-18, div.span-19, div.span-20,
div.span-21, div.span-22, div.span-23, div.span-24 {
	float: left;
	margin-right: 10px;
}

/* The last column in a row needs this class. */
div.last { margin-right: 0; }

/* Use these classes to set the width of a column. */
.span-1  { width: 30px; }
.span-2  { width: 70px; }
.span-3  { width: 110px; }
.span-4  { width: 150px; }
.span-5  { width: 190px; }
.span-6  { width: 230px; }
.span-7  { width: 270px; }
.span-8  { width: 310px; }
.span-9  { width: 350px; }
.span-10 { width: 390px; }
.span-11 { width: 430px; }
.span-12 { width: 470px; }
.span-13 { width: 510px; }
.span-14 { width: 550px; }
.span-15 { width: 590px; }
.span-16 { width: 630px; }
.span-17 { width: 670px; }
.span-18 { width: 710px; }
.span-19 { width: 750px; }
.span-20 { width: 790px; }
.span-21 { width: 830px; }
.span-22 { width: 870px; }
.span-23 { width: 910px; }
.span-24, div.span-24 {
	margin: 0;
	width: 950px;
}

/* Add these to a column to append empty cols. */
.append-1  { padding-right: 40px; }
.append-2  { padding-right: 80px; }
.append-3  { padding-right: 120px; }
.append-4  { padding-right: 160px; }
.append-5  { padding-right: 200px; }
.append-6  { padding-right: 240px; }
.append-7  { padding-right: 280px; }
.append-8  { padding-right: 320px; }
.append-9  { padding-right: 360px; }
.append-10 { padding-right: 400px; }
.append-11 { padding-right: 440px; }
.append-12 { padding-right: 480px; }
.append-13 { padding-right: 520px; }
.append-14 { padding-right: 560px; }
.append-15 { padding-right: 600px; }
.append-16 { padding-right: 640px; }
.append-17 { padding-right: 680px; }
.append-18 { padding-right: 720px; }
.append-19 { padding-right: 760px; }
.append-20 { padding-right: 800px; }
.append-21 { padding-right: 840px; }
.append-22 { padding-right: 880px; }
.append-23 { padding-right: 920px; }

/* Add these to a column to prepend empty cols. */
.prepend-1  { padding-left: 40px; }
.prepend-2  { padding-left: 80px; }
.prepend-3  { padding-left: 120px; }
.prepend-4  { padding-left: 160px; }
.prepend-5  { padding-left: 200px; }
.prepend-6  { padding-left: 240px; }
.prepend-7  { padding-left: 280px; }
.prepend-8  { padding-left: 320px; }
.prepend-9  { padding-left: 360px; }
.prepend-10 { padding-left: 400px; }
.prepend-11 { padding-left: 440px; }
.prepend-12 { padding-left: 480px; }
.prepend-13 { padding-left: 520px; }
.prepend-14 { padding-left: 560px; }
.prepend-15 { padding-left: 600px; }
.prepend-16 { padding-left: 640px; }
.prepend-17 { padding-left: 680px; }
.prepend-18 { padding-left: 720px; }
.prepend-19 { padding-left: 760px; }
.prepend-20 { padding-left: 800px; }
.prepend-21 { padding-left: 840px; }
.prepend-22 { padding-left: 880px; }
.prepend-23 { padding-left: 920px; }


/* Border on right hand side of a column. */
div.border {
	border-right: 1px solid #eee;
	margin-right: 5px;
	padding-right: 4px;
}

/* Border with more whitespace, spans one column. */
div.colborder {
	border-right: 1px solid #eee;
	margin-right: 25px;
	padding-right: 24px;
}


/* Use these classes on an element to push it into the
   next column, or to pull it into the previous column.  */

.pull-1 { margin-left: -40px; }
.pull-2 { margin-left: -80px; }
.pull-3 { margin-left: -120px; }
.pull-4 { margin-left: -160px; }
.pull-5 { margin-left: -200px; }

.pull-1, .pull-2, .pull-3,
.pull-4, .pull-5, .pull-5 {
	float:left;
	position:relative;
}

.push-1 { margin: 0 -40px 1.5em 40px; }
.push-2 { margin: 0 -80px 1.5em 80px; }
.push-3 { margin: 0 -120px 1.5em 120px; }
.push-4 { margin: 0 -160px 1.5em 160px; }
.push-5 { margin: 0 -200px 1.5em 200px; }

.push-0, .push-1, .push-2,
.push-3, .push-4, .push-5 {
	float: right;
	position:relative;
}

/* @end */

/* @end Blueprint */

/* @group Reset */

table {
	border-collapse: separate;
	border-spacing: 0;
}

caption, th, td {
	text-align: left;
	font-weight: 400;
}

a img {
	border: none;
}

/* @end */

/* @group Page layout */

body {
	font: 12px/20px "Lucida Grande", Lucida, Verdana, sans-serif;
	margin: 0;
	padding: 30px 40px 0;
	background-repeat: no-repeat;
}

#content {
	width: 770px;
	float: left;
	padding-right: 21px;
	border-right: 1px solid silver;
	margin-top: 142px;
	padding-bottom: 110px;
}

#content.edit {
	width: 100%;
	padding-right: 0;
	border-style: none;
}

#navigation {
	width: 190px;
	font-size: 10px;
	float: left;
	margin-top: -50px;
}

#content.edit #navigation {
	display: none;
}

#mainContent {
	float: right;
	width: 510px;
	margin-right: 40px;
	padding-bottom: 40px;
}

#content.edit #mainContent {
	float: left;
	padding-right: 40px;
	border-right: 1px solid silver;
}



/* @end */

/* @group Simulation */

#simulation {
	width: 590px;
	font: 13px/20px "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
	display: block;
	color: #4b4540;
	padding: 0 40px 40px;
	background: #e9e9e8;
	float: left;
	margin-right: -30px;
	zoom: 82.47%;
}

#simulation .focus {
	background-color: #fdfdc8;
}

@media only screen and (max-width: 1210px) {

#simulation {
	zoom: 67%;
}

}

@media only screen and (min-width: 1350px) {

#simulation {
	zoom: 100%;
}

}

#simulation h1 {
	margin: 0 -40px 20px;
	text-shadow: 0px 1px 0px rgba(255, 255, 255,1);
	background: #c8c3be;
	line-height: 38px;
	font-weight: lighter;
	font-size: 35px;
	padding: 25px 20px 15px 40px;
}

#simulation h2 {
	margin-bottom: 20px;
	margin-top: 0;
	line-height: 20px;
	font-weight: bold;
	font-size: 16px;
}

#simulation fieldset p.legend {
	width: 95%;
	font-weight: normal;
	font-style: normal;
	color: #3f3f3f;
	margin-bottom: 0;
}

#simulation div.message,
#simulationp.message {
	padding: 10px;
	-webkit-box-shadow: 0 0 10px rgba(0,0,0,0.3);
	-moz-box-shadow: 0 0 10px rgba(0,0,0,0.3);
	box-shadow: 0 0 10px rgba(0,0,0,0.3);
	margin-bottom: 20px;
	clear: left;
	float: left;
	width: 570px;
}

#simulation div.emphasis,
#simulation p.emphasis {
	border: 4px double silver;
	width: 563px;
}

#simulation ol.form-iteration {
	list-style-type: none;
	margin: 0;
}

#simulation ol.form-iteration li {
	list-style-type: none;
	margin: 0;
	padding: 0;
}

#simulation ol.form-iteration li:before {
	display: none;
}

/* @group Gallery */

#simulation .gallery {
	width: 170px;
	float: left;
	margin-bottom: 0;
}

#simulation .gallery a {
	float: left;
	margin-bottom: 10px;
	text-align: center;
	width: 45px;
	height: 45px;
	margin-right: 10px;
}

#simulation .gallery a:first-child {
	width: 155px;
	height: auto;
	margin-right: 0;
}

#simulation .gallery img {
	max-width: 45px;
	max-height: 45px;
	float: none;
	cursor: pointer;
	margin-top: 0;
	margin-right: 0;
	margin-bottom: 0;
}

#simulation .gallery a:first-child img {
	max-height: 500px;
	max-width: 155px;
	width: 155px;
	float: left;
}



/* @end */

/* @group Fieldset Comprehensive */

#simulation .comprehensive,
#simulation .comprehensive fieldset,
#simulation .concise fieldset.comprehensive,
#simulation .compact fieldset.comprehensive {
	width: 50%;
    clear: left; /* Reverted: removing this breaks the evaluation form in FF */
	border-bottom: 1px solid silver;
	padding-left: 50%;
	margin-bottom: 20px;
}

#simulation fieldset.comprehensive label,
#simulation form.comprehensive fieldset label,
#simulation form.concise fieldset.comprehensive label,
#simulation form.compact fieldset.comprehensive label {
	font-weight: normal;
	font-style: normal;
	position: static;
	margin: 0;
	padding: 0;
	float: none;
	width: auto;
}

#simulation .concise fieldset.comprehensive,
#simulation .condensed fieldset.comprehensive {
	border-bottom-style: none;
	padding-bottom: 0;
}

#simulation fieldset.comprehensive label *,
#simulation form.comprehensive fieldset label *,
#simulation form.concise fieldset.comprehensive label *,
#simulation fieldset.concise #simulation fieldset.comprehensive label *,
#simulation form.compact fieldset.comprehensive label *
 {
	position: static;
	margin-right: 0;
	float: none;
	vertical-align: baseline;
}

#simulation fieldset.comprehensive p.legend,
#simulation form.comprehensive fieldset p.legend,
#simulation form.concise fieldset.comprehensive p.legend,
form.compact fieldset.comprehensive p.legend {
	width: 90% !important;
	display: inline;
	text-align: left;
	margin-right: 0;
	padding: 0;
	margin-bottom: 4px;
	float: left;
	margin-left: -100%;
}

/* @end */

/* @group Buttons */

#simulation .buttonBar {
	margin-bottom: 20px;
	width: 100%;
	float: left;
}

#simulation .buttonBar.super {
	float: right;
	width: auto;
	margin-top: -70px;
}

#simulation .buttonBar.super button.floatAfter {
	margin-left: 10px;
	position: static;
	float: right;
	margin-right: 0;
}

#simulation button,
#simulation .button-medium,
#simulation .accordion dt {
	position: relative;
	padding: 5px 20px 6px;
	margin-right: 10px;
	margin-left: 0;
	color: #c8c3be;
	border: 1px solid #7f7f7f;
	text-shadow: 0px -1px 0px rgba(0,0,0,1);
	line-height: 17px;
	border-bottom: 1px solid #7f7f7f;
	font-size: 13px;
	-webkit-transition: all 0.3s;
	text-decoration: none !important;
	background-color: #332e29;
	background-image: url(button-default.png);
	background: -webkit-gradient(linear, 0% 100%, 0% 0%, from(#413C37), to(#726D68));
	cursor: default !important;
	display: inline-block;
}

#simulation button:active,
#simulation .button-medium:active,
#simulation .accordion dt:active {
	background: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#413C37), to(#726D68));
	text-shadow: rgba(0,0,0,0.5) 0 2px 3px;
}

#simulation button.small,
#simulation .button-small,
#simulation .button.small,
#simulation .solutions ol li:before {
	position: relative;
	padding: 2px 6px 3px;
	margin-right: 5px;
	margin-left: 0;
	background-image: url(button-default.png);
	color: #c8c3be;
	border: 1px solid #7f7f7f;
	text-shadow: 0px -1px 0px rgba(0,0,0,1);
	background-color: #332e29;
	-webkit-background-size: 100%;
	-moz-background-size: 100%;
	background-size: 100%;
	line-height: 9px;
	border-bottom: 1px solid #7f7f7f;
	font-size: 9px;
	-webkit-transition: all 0.3s;
	text-decoration: none;
	cursor: default;
	top: -2px;
	display: inline-block;
}

#simulation button:hover,
#simulation .button-medium:hover {
	color: white;
	border: 1px solid #332e29;
}

#simulation button.floatBefore,
#simulation .button-medium.floatBefore {
	float: right;
	right: 50%;
}

#simulation button.floatAfter,
#simulation .button-medium.floatAfter {
	float: left;
	left: 50%;
}

#simulation button.back,
#simulation .button-medium.back {
	background-image: none;
	background-color: transparent;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	box-shadow: none;
	text-shadow: 0px 1px 0px rgba(255,255,255,0.6);
	color: #7f7f7f;
	border-style: none;
	border-bottom-style: solid;
	padding: 6px 0 0;
	cursor: pointer;
}

#simulation button.back:hover,
#simulation .button-medium.back:hover {
	color: #332e29;
	border-bottom: 1px solid #332e29;
}

#simulation a.button-medium.back {
	padding-top: 8px;
}

#simulation button.link {
	background-image: none;
	background-color: transparent;
	padding: 0;
	margin: 0;
	display: inline-block;
	border-style: none;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	box-shadow: none;
	text-shadow: none;
	text-decoration: underline !important;
	cursor: pointer !important;
	letter-spacing: 0;
}

#simulation #simulation button[disabled="disabled"],
#simulation .button.disabled,
#simulation button[disabled="disabled"]:hover,
#simulation .button.disabled:hover,
#simulation button:disabled {
	opacity: 0.6;
	color: gray;
}


/* @end */



/* @end */

/* @group Grid list */

dl.grid {
	margin-bottom: 18px;
	float: left;
}

dl.grid dt {
	width: 35%;
	float: left;
	font-weight: bold;
	clear: left;
	padding-right: 5px;
}

dl.grid dd {
	width: 65%;
	margin-right: -100%;
	display: inline-block;
	float: left;
	margin-bottom: 0;
	margin-left: 0;
	white-space: pre-line;
}

dl.grid dt label {
	width: auto !important;
	padding: 0 !important;
	color: black !important;
}

/* @end */

/* @group Navigation tree */

.navigation {
	margin: 0;
	padding: 0 0 20px;
	line-height: 15px;
}

.navigation ul {
	border-left: 1px solid silver;
	margin-left: 2px;
	padding-left: 6px;
	margin-right: 0;
	margin-bottom: 0 !important;
}

.navigation .active>ul {
	border-left: 1px solid silver;
	margin-left: 2px;
	padding-left: 6px;
	display: block;
}

.navigation li {
	margin: 0;
	padding: 0 !important;
	list-style-type: none;
	position: relative;
}

.navigation li.active {
	background-color: #ebebeb;
}

.navigation li.active em.icon {
	background-position-y: -16px;
}

.navigation li.current a {
	color: black;
}

.navigation li.current a.state-draft {
	color: #ff8100;
}

.navigation li.current a.state-draft:hover {
	color: #c26106;
}

.navigation li a {
	padding-left: 20px;
	display: block;
	text-decoration: none;
	padding-bottom: 8px;
	padding-right: 5px;
}

.navigation li a:hover {
	text-decoration: underline;
}

.navigation em.icon,
.navigation img {
	background-color: #00a1e0;
	position: absolute;
	top: -3px;
	left: 0;
	border-style: none;
}

.navigation a:hover img,
.navigation .current img,
.navigation a:hover em.icon {
	background-color: #007fb1;
}

.navigation a.state-draft em.icon,
.navigation a.state-draft  img {
	position: absolute;
	border-style: none;
	background-color: #ff8100;
}

.navigation .current a:hover em.icon {
	background-color: black;
}

.navigation a.state-draft:hover img,
.navigation .current.state-draft img,
.navigation a.state-draft:hover em.icon {
	background-color: #c26106;
}

.navigation .current em.icon {
	background-color: #515151;
}

.navigation .current a:hover {
	color: black;
}



/* @end */

/* @group Floats */

.floatBefore {
	float: left;
}

.floatAfter {
	float: right;
}

img.floatBefore {
	margin-right: 10px;
}

img.floatAfter {
	margin-left: 10px;
}



/* @end */

/* @group Site menu
 */

iframe#siteMenu,
object#siteMenu {
	position: absolute;
	top: 0;
	right: 0;
	border-style: none;
	height: 30px;
	overflow: hidden;
	width: 500px;
	z-index: 2000;
	background-color: transparent;
}

ul#siteMenu
 {
	position: absolute;
	top: 0;
	right: 10px;
	list-style-type: none;
	font-size: 10px;
}

body.siteMenu {
	overflow: hidden;
	background-color: transparent;
}

ul#siteMenu li
 {
	float: right;
	color: black;
}

ul#siteMenu > li > a
 {
	text-decoration: none;
	color: white;
	padding: 3px 7px;
	display: inline-block;
	position: relative;
	background: url(siteMenu-top.png) no-repeat center 22px;
	height: 25px;
	z-index: 11;
	-webkit-transition: all 0.3s;
}

ul#siteMenu > li:hover > a {
	background-position: center 12px;
}

ul#siteMenu li a:hover {
	text-decoration: underline;
}

ul#siteMenu li#user a {
}

/* @group Submenu */

ul#siteMenu > li > ul {
	visibility: hidden;
	position: absolute;
	top: 30px;
	right: 8px;
	list-style-type: none;
	margin: 0;
	display: block;
	padding: 0;
	width: 100%;
	-webkit-box-shadow: 0 0 15px rgba(0,0,0,0.3);
	-moz-box-shadow: 0 0 15px rgba(0,0,0,0.3);
	-o-box-shadow: 0 0 15px rgba(0,0,0,0.3);
	box-shadow: 0 0 15px rgba(0,0,0,0.3);
	background-color: #eee;
	border: 1px solid silver;
}

ul#siteMenu > li > ul > li {
	padding: 10px;
	clear: left;
	display: block;
	float: none;
	font-weight: bold;
}

ul#siteMenu > li > ul > li ul {
	margin: 0 -10px;
	padding: 0;
}

ul#siteMenu > li > ul > li ul li {
	list-style-type: none;
	float: none;
}

ul#siteMenu > li > ul > li ul li a {
	display: block;
	color: gray;
	font-weight: normal;
	font-style: normal;
	padding-left: 10px;
	padding-right: 10px;
}

ul#siteMenu > li > ul > li ul li a:hover {
	color: #515151;
	background-color: #dbdbdb;
	text-decoration: none;
}

ul#siteMenu li.open ul {
	visibility: visible;
	z-index: 10;
}



/* @end */

/* @group Style help */

/*iframe#siteMenu {
	height: 100%;
}

ul#siteMenu li ul {
	visibility: visible;
}*/

/* @end */



/* @end */

/* @group Typography */

p {
	margin-bottom: 20px;
	margin-top: 0;
}

a {
	color: #179cd8;
}

a:hover {
	color: #1286bb;
}

/* @group Headings */

h1 {
	font-size: 25px;
	line-height: 30px;
	font-weight: normal;
	font-style: normal;
	letter-spacing: 1px;
	margin-bottom: 20px;
	margin-top: -55px;
}

.floatingPanel-modal h1 {
	font-size: 17px;
	counter-increment: section;
	counter-reset: subsection;
	font-weight: bold;
	margin-bottom: 20px;
	height: auto;
	min-height: 0;
	width: auto;
	padding: 0;
	margin-top: 0;
}

h2 {
	font-size: 17px;
	counter-increment: section;
	counter-reset: subsection;
	margin-bottom: 20px;
	font-weight: normal;
	margin-top: 0;
	clear: left;
}

h3 {
	font-size: 12px;
	line-height: 20px;
	text-transform: uppercase;
	letter-spacing: 5px;
	margin-bottom: 20px;
	font-weight: bold;
	margin-top: 0;
}

h4 {
	font-size: 12px;
	line-height: 20px;
	text-transform: uppercase;
	letter-spacing: 5px;
	margin-bottom: 6px;
	margin-top: 0;
}

h5 {
	font-size: 12px;
	line-height: 20px;
	margin-bottom: 4px;
	min-height: 1.25em;
	font-weight: bold;
	margin-top: 0;
}

h1 img, h2 img, h3 img,
h4 img, h5 img, h6 img {
	margin: 0;
}

/* @end */

/* @group Text Elements */

p {
	margin: 0 0 20px;
}

.introduction * {
	font-weight: bold;
}

.discrete,
.discrete * {
	font-size: 10px;
	font-style: italic;
	color: gray;
}

.discrete a {
	color: #00a1e0;
}

.discrete a:hover {
	text-decoration: underline;
}

p.byline {
	margin-top: -16px;
	margin-bottom: 14px;
}

p img.right {
	float: right;
	margin: 1.5em 0 1.5em 1.5em;
}

a:focus,
a:hover {
	color: #007fb1;
	text-decoration: underline;
}

a {
	color: #00a1e0;
	text-decoration: none;
	cursor: pointer;
}

a.external-link:before {
	content: "";
	display: inline-block;
	width: 16px;
	height: 16px;
	margin-bottom: -4px;
	margin-top: -4px;
	background: #217efb url(icons.png) -1071px 0;
	border-right: 2px solid white;
}

a.external-link:hover:before {
	background-color: #007fb1;
}

a.state-draft {
	color: #ff8100;
}

a.state-draft:hover {
	color: #c26106;
}

a * {
	cursor: pointer;
}

blockquote {
	margin: 1.5em;
	color: #8e8e8e;
	letter-spacing: 1px;
	font: italic normal 20px/30px Georgia, "Times New Roman", Times, serif;
	text-align: center;
}

blockquote:before {
	content: "“";
	font-size: 310px;
	z-index: 0;
	color: #efeeef;
	width: 70px;
	margin: 102px -40px -120px;
	float: left;
}

#mainContent blockquote:before {
	font-size: 240px;
	margin-top: 64px;
	margin-left: -33px;
}

strong {
	font-weight: bold;
}

em,dfn {
	font-style: italic;
}

dfn {
	font-weight: bold;
}

sup, sub {
	line-height: 0;
	letter-spacing: 0;
}

h1 sup {
	font-size: 14px;
	letter-spacing: 0;
	color: gray;
	font-weight: normal;
	font-style: normal;
}

h3 sup {
	font-size: 8px;
	letter-spacing: 0;
	color: gray;
}

abbr,
acronym {
	border-bottom: 1px dotted #666;
}

address {
	margin: 0 0 1.5em;
	font-style: italic;
}

del {
	color: #666;
}

pre {
	background-color: #efefef;
	display: block;
	overflow: auto;
	-webkit-box-shadow: 0 2px 10px rgba(0,0,0,0.35);
	-moz-box-shadow: 0 2px 10px rgba(0,0,0,0.35);
	box-shadow: 0 2px 10px rgba(0,0,0,0.35);
	padding: 10px;
	margin-bottom: 20px;
}

pre,code {
	white-space: pre;
	background-color: #efefef;
}

pre,code,tt {
	font: 13px 'andale mono', 'lucida console', monospace;
}

code {
	padding: 3px;
	margin: -3px;
	color: #515151 !important;
	text-shadow: white 0 1px 0;
	background-color: #e0e0e0;
	font-style: normal !important;
}

em.unknown {
	color: silver;
	font-weight: normal;
}

/* @end */

/* @group Lists */

li ul,
li ol {
	margin: 0 0 0 20px;
}

ul, ol {
	margin-top: 0;
	margin-bottom: 20px;
	margin-left: 0;
	padding-left: 40px;
}

ul {
	list-style-type: disc;
}

ul ul {
	list-style-type: circle;
	margin-bottom: 0;
}

ul li {
	padding-left: 0;
}

ol {
	counter-reset: numsection;
	list-style-type: none;
	margin-left: 0;
	padding-left: 0;
	padding-bottom: 20px;
}

ol li {
	padding-left: 40px;
}

ol li:before {
	counter-increment: numsection;
	content: counter(numsection) ".";
	width: 30px;
	display: block;
	margin-left: -40px;
	float: left;
}

/* @end */

/* @group Definition List */

dl {
	margin-bottom: 20px;
}

dt {
	font-weight: bold;
}

dt em.icon {
	position: relative;
	top: 2px;
}

dd {
	margin: 0 0 20px 20px;
}

/* @end */

/* @group Tables */

table {
	margin-bottom: 20px;
	position: relative;
	width: 100%;
	font-size: 12px;
}

tbody th {
	font-weight: bold;
}

thead th {
	font-weight: bold;
	border-bottom: 1px solid #179cd8;
}

th,td {
	padding: 4px 10px 4px 0;
	vertical-align: top;
}

th>.icon,td>.icon {
	margin-top: 1px;
}

table.outdent tbody tr th {
	width: 190px;
}

/*tbody tr:hover {
	background: rgba(0,161,224,0.12);
}*/

td.emphasis,th.emphasis {
	background: rgba(255,208,0,0.2);
	text-align: center;
	padding-right: 0;
	font-weight: bold;
}

tr.current td {
	background: rgba(255,208,0,0.2);
	font-weight: bold;
	color: #6f5a44;
}

tr.current td a {
	font-weight: bold;
	color: #6f5a44;
}

tfoot {
	font-style: italic;
}

tbody {
	border-bottom: 1px solid #179cd8;
	margin-bottom: 80px;
}

tbody tr:last-child td,tbody tr:last-child th {
	border-bottom: 1px solid #179cd8;
	padding-bottom: 8px;
}

tbody h3 {
	margin-bottom: -4px;
	border-bottom: 1px solid #179cd8;
	padding-bottom: 12px;
	margin-right: -10px;
	padding-top: 28px;
	background-color: white;
	margin-top: -4px;
}

caption {
	caption-side: bottom;
	height: 133px;
	z-index: 0;
	margin-bottom: -155px;
	margin-top: 15px;
	position: relative;
	top: 10px !important;
}

thead th {
	vertical-align: bottom;
}

tr.diagonal th {
	height: 80px;
}

tr.diagonal th h5 {
	-webkit-transform: rotate(-45deg);
	-webkit-transform-origin: bottom left;
	-moz-transform: rotate(-45deg);
	-moz-transform-origin: bottom left;
	transform: rotate(-45deg);
	transform-origin: bottom left;
	position: absolute;
	margin-top: -20px;
	margin-left: 7px;
	width: 140px;
}

table.high-density {
	font-size: 10px;
	margin-left: -200px;
	width: 710px;
}

table.high-density tbody tr th {
	width: 190px;
}

table.high-density th,table.high-density td {
	font-size: 10px;
	padding-right: 4px;
	padding-top: 2px;
	padding-bottom: 2px;}

td a.button.micro, td button.micro {
	margin-top: -1px;
	margin-bottom: -3px;
}

td.actions {
	white-space: nowrap;
}

/* @end */



/* @end */

/* @group Search */

#tabs #search {
	padding-top: 17px;
	padding-left: 15px;
	border-top-style: none;
	margin-top: 30px;
	position: relative;
	background-color: transparent;
}

#tabs #search:before {
	content: "|";
	float: left;
	margin-left: -16px;
	width: 1px;
	background-color: white;
	height: 90px;
	margin-top: -49px;
	overflow: hidden;
}

#tabs #search form {
	margin: 0;
	padding: 0;
}

#tabs #search form input {
	border-style: none;
	font-size: 12px;
	line-height: 19px;
	padding-left: 8px;
	padding-bottom: 0;
	padding-top: 0;
	margin-bottom: -1px;
	margin-top: 0;
}

#tabs #search form button {
	display: none;
}

#tabs #search form label {
	position: absolute;
	color: gray;
	left: 20px;
	top: 17px;
}



/* @end */

/* @group Tabs */

#tabs {
	position: absolute;
	top: 0;
	left: 0;
	list-style-type: none;
	margin: 0;
	padding: 0 0 0 260px;
	background-color: #179cd8;
	right: 0;
	height: 70px;
	overflow: hidden;
	background: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#63ADD8), to(#1277A6));
	background: -moz-linear-gradient(19% 75% 90deg,#63ADD8, #1277A6, #C7C7C7 100%);
}

#tabs li {
	margin: 0;
	float: left;

	background-color: white;
	padding-top: 30px;
}

#tabs li a {
	display: block;
	line-height: 20px;
	text-decoration: none;
	border-left: 1px solid #469fc2;
	height: 23px;
	padding-top: 17px;
	padding-left: 15px;
	padding-right: 15px;
}

#tabs li.current a {
	background-color: #ebebeb;
	color: #787878;
}

#tabs li a:hover {
	color: white;
	background-color: #179cd8;
	background: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#63ADD8), to(#1277A6));
	background: -moz-linear-gradient(19% 75% 90deg,#63ADD8, #1277A6);
}

#tabs li a:active {
	background: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#1277A6), to(#63ADD8));
	background: -moz-linear-gradient(19% 75% 90deg,#1277A6, #63ADD8, #C7C7C7 100%);
	text-shadow: black 0 1px 6px;
}

#home {
	position: absolute;
	top: 0;
	left: 0;
}

#tabs #home a {
	width: 260px;
	text-indent: -1000px;
	padding: 0;
	background: url(logo.png) no-repeat 40px center;
	border-style: none;
	height: 40px;
}



/* @end */

/* @group Appendix */

#appendix {
	text-align: center;
	padding-top: 30px;
	padding-bottom: 20px;
	z-index: 0;
	font-size: 10px;
	color: silver;
	width: 100%;
	margin-top: -80px;
	clear: both;
}

#appendix a {
	text-decoration: none;
}

#appendix a:hover {
	text-decoration: underline;
}



/* @end */

/* @group Iconography */

em.icon,
a.icon,
a.button.icon {
	width: 16px;
	height: 16px;
	display: inline-block;
	text-indent: -1000px;
	overflow: hidden;
	background: #3f3f3f url(icons.png) 0 0;
}

a.icon {
	background-color: #00a1e0;
}

a.icon:hover {
	background-color: #007fb1;
}

h1 .icon {
	position: relative;
	top: -9px;
}

h2 em.icon {
	background-color: black;
	margin-top: 3px;
	margin-right: 2px;
	float: left;
}

h5 em.icon {
	background-color: black;
	margin-top: 1px;
	margin-right: 2px;
	float: left;
}

h3 em.icon {
	background-color: black;
	margin-top: -2px;
	margin-right: 2px;
	float: left;
}

p em.icon, ul li em.icon {
	position: relative;
	top: 2px;
	margin-top: 2px;
}

a em.icon {
	background-color: #00a1e0;
}

a:hover em.icon {
	background-color: #007fb1;
}

button em.icon,
button.sublime:hover em.icon,
a.sublime:hover em.icon  {
	position: relative;
	left: -4px;
	display: inline-block;
	margin: -2px -2px -3px 1px !important;
	line-height: 17px;
	top: 0 !important;
}

button.icon strong {
	display: none;
}

button.icon em.icon {
	position: relative;
	left: -1px;
}

a.icon.button,
em.icon.button {
	-webkit-border-radius: 8px;
	-o-border-radius: 8px;
	-moz-border-radius: 8px;
	border-radius: 8px;
	padding: 0 !important;
	letter-spacing: -1000px;
	border-style: none;
	background-color: #d6d6d6;
}

a.icon.button:hover {
	background-color: #bebebe;
}



/* @group Icon base */

#pageOptions a.icon {
	padding: 0 !important;
	height: 22px !important;
	overflow: hidden;
	line-height: 100px !important;
	position: relative;
	text-align: center;
	text-indent: 1000px;
	width: 22px;
}

#pageOptions a.icon:before {
	display: block;
	text-align: center;
	vertical-align: middle;
	text-indent: 0;
	font: 25px/0 Icons;
	padding: 0 10px !important;
	margin-top: 12px;
}

/* @end */

/* @group Icons lists */

.iconList li {
	position: relative;
}

.iconList li:before {
	float: left;
	margin-right: 3px;
	margin-top: -2px;
	position: absolute;
	left: 10px;
	top: 5px;
	margin-left: 2px;
	color: #5d5d5d;
	width: 16px;
	height: 16px;
	text-indent: -99999px;
	background-color: #5d5d5d;
	background-image: url(icons.png);
}

.iconList li:hover:before {
	background-position-y: 0 !important;
	background-color: black;
}

.iconList li:hover:active:before {
	background-color: #FF7B00;
}

/* @end */

/* @group Injecticons */

.iconList li.cut:before {
	content: "cut";
	background-position: -304px -16px;
}

.iconList li.copy:before {
	content: "copy";
	background-position: -320px -16px;
}

.iconList li.paste:before {
	content: "paste";
	background-position: -336px -16px;
}

.iconList li.blog:before {
	content: "blog";
	background-position: -144px -16px;
}

.iconList li.richPage:before {
	content: "page";
	background-position: -224px -16px;
}

.iconList li.permissions:before {
	content: "permissions";
	background-position: -352px -16px;
}

.iconList li.properties:before {
	content: "properties";
	background-position: -368px -16px;
}

.iconList li.media:before {
	content: "media";
	background-position: -1005px -16px;
}

.iconList li.file:before {
	content: "file";
	background-position: -272px -16px;
}

.iconList li.screen:before {
	content: "screen";
	background-position: -80px -16px;
}

.iconList li.folder:before {
	content: "folder";
	background-position: 0 -16px;
}

.iconList li.annotation:before {
	content: "annotation";
	background-position: -592px -16px;

}

.iconList li.generate:before {
	content: "generate";
	background-position: -576px -16px;

}

.iconList li.project:before {
	content: "Project";
	background-position: -128px -16px;

}

.iconList li.ploneGlossary:before {
	content: "Glossary";
	background-position: -752px -16px;

}

.iconList li.event:before {
	content: "Glossary";
	background-position: -512px -16px;
}

.iconList li.issueTracker:before {
	content: "Glossary";
	background-position: -240px -16px;
}

}

/* @end */

/* @group Extra classes needed only for Gecko */

/* @group Icons in lists */

.active em.icon.folder {
	background-position: 0 -16px;
}
.active em.icon.organicer {
	background-position: 0 -16px;
}

.active em.icon.prototype {
	background-position: -32px -16px;
}

.active em.icon.element {
	background-position: -48px -16px;
}

.active em.icon.component {
	background-position: -64px -16px;
}

.active em.icon.screen {
	background-position: -80px -16px;
}

.active em.icon.template {
	background-position: -96px -16px;
}

.active em.icon.persona {
	background-position: -112px -16px;
}

.active em.icon.project {
	background-position: -128px -16px;
}

.active em.icon.add {
	background-position: -144px -16px;
}

.active em.icon.priorityMinor {
	background-position: -160px -16px;
}

.active em.icon.priorityNormal {
	background-position: -176px -16px;
}

.active em.icon.priorityCritical {
	background-position: -192px -16px;
}

.active em.icon.adl {
	background-position: -208px -16px;
}

.active em.icon.richPage {
	background-position: -224px -16px;
}

.active em.icon.issueTracker {
	background-position: -240px -16px;
}

.active em.icon.simpleBlog {
	background-position: -256px -16px;
}

.active em.icon.file {
	background-position: -272px -16px;
}

.active em.icon.newPage {
	background-position: -288px -16px;
}

.active em.active em.icon.cut {
	background-position: -304px -16px;
}

.active em.icon.copy {
	background-position: -320px -16px;
}

.active em.icon.paste {
	background-position: -336px -16px;
}

.active em.icon.permissions {
	background-position: -352px -16px;
}

.active em.icon.pageProperties {
	background-position: -368px -16px;
}

.active em.icon.twistyOpen {
	background-position: -384px -16px;
}

.active em.icon.twistyExpanded {
	background-position: -400px -16px;
}

.active em.icon.edit {
	background-position: -416px -16px;
}

.active em.icon.info {
	background-position: -432px -16px;
}

.active em.icon.issue {
	background-position: -448px -16px;
}

.active em.icon.zoom {
	background-position: -464px -16px;
}

.active em.icon.discussion {
	background-position: -480px -16px;
}

.active em.icon.ency {
	background-position: -496px -16px;
}

.active em.icon.event {
	background-position: -512px -16px;
}

.active em.icon.faq {
	background-position: -528px -16px;
}

.active em.icon.favorite {
	background-position: -544px -16px;
}

.active em.icon.formulaDoc {
	background-position: -560px -16px;
}

.active em.icon.generate {
	background-position: -576px -16px;
}

.active em.icon.annotation {
	background-position: -592px -16px;
}

.active em.icon.content {
	background-position: -608px -16px;
}

.active em.icon.documentation {
	background-position: -624px -16px;
}

.active em.icon.module {
	background-position: -640px -16px;
}

.active em.icon.job {
	background-position: -656px -16px;
}

.active em.icon.libraryItem {
	background-position: -672px -16px;
}

.active em.icon.link {
	background-position: -688px -16px;
}

.active em.icon.lock {
	background-position: -704px -16px;
}

.active em.icon.personaeFolder {
	background-position: -720px -16px;
}

.active em.icon.plfng {
	background-position: -736px -16px;
}

.active em.icon.ploneGlossary {
	background-position: -752px -16px;
}

.active em.icon.portlet {
	background-position: -768px -16px;
}

.active em.icon.question {
	background-position: -784px -16px;
}

.active em.icon.scenario {
	background-position: -800px -16px;
}

.active em.icon.topic {
	background-position: -816px -16px;
}

.active em.icon.projectGeneric {
	background-position: -832px -16px;
}

.active em.icon.projectConceptDesign {
	background-position: -848px -16px;
}

.active em.icon.projectApplicationDesign {
	background-position: -864px -16px;
}

.active em.icon.action {
	background-position: -880px -16px;
}

.active em.icon.media {
	background-position: -1005px -16px;
}

.active em.icon.blog {
	background-position: -16px -16px;
}



/* @end */

/* @group Buttons */

button em.icon.folder {
	background-position: 0 -64px;
	background-color: transparent;
}

button em.icon.blog {
	background-position: -16px -32px;
}

button em.icon.organicer {
	background-position: 0 -32px;
}

button em.icon.prototype {
	background-position: -32px -32px;
}

button em.icon.element {
	background-position: -48px -32px;
}

button em.icon.component {
	background-position: -64px -32px;
}

button em.icon.screen {
	background-position: -80px -32px;
}

button em.icon.template {
	background-position: -96px -32px;
}

button em.icon.persona {
	background-position: -112px -32px;
}

button em.icon.project {
	background-position: -128px -32px;
}

button em.icon.add {
	background-position: -144px -32px;
}

button em.icon.priorityMinor {
	background-position: -160px -32px;
}

button em.icon.priorityNormal {
	background-position: -176px -32px;
}

button em.icon.priorityCritical {
	background-position: -192px -32px;
}

button em.icon.adl {
	background-position: -208px -32px;
}

button em.icon.richPage {
	background-position: -224px -64px;
	background-color: transparent;
}

button em.icon.issueTracker {
	background-position: -240px -32px;
}

button em.icon.simpleBlog {
	background-position: -256px -32px;
}

button em.icon.file {
	background-position: -272px -64px;
	background-color: transparent;
}

button em.icon.newPage {
	background-position: -288px -32px;
}

button em.icon.cut {
	background-position: -304px -32px;
}

button em.icon.copy {
	background-position: -320px -32px;
}

button em.icon.paste {
	background-position: -336px -32px;
}

button em.icon.permissions {
	background-position: -352px -32px;
}

button em.icon.pageProperties {
	background-position: -368px -32px;
}

button em.icon.twistyOpen {
	background-position: -384px -32px;
}

button em.icon.twistyExpanded {
	background-position: -400px -32px;
}

button em.icon.edit {
	background-position: -416px -32px;
}

button em.icon.info {
	background-position: -432px -32px;
}

button em.icon.issue {
	background-position: -448px -32px;
}

button em.icon.zoom {
	background-position: -464px -32px;
}

button em.icon.discussion {
	background-position: -480px -32px;
}

button em.icon.ency {
	background-position: -496px -32px;
}

button em.icon.event {
	background-position: -512px -32px;
}

button em.icon.faq {
	background-position: -528px -32px;
}

button em.icon.favorite {
	background-position: -544px -32px;
}

button em.icon.formulaDoc {
	background-position: -560px -32px;
}

button em.icon.generate {
	background-position: -576px -32px;
}

button em.icon.annotation {
	background-position: -592px -64px;
	background-color: transparent;
}

button em.icon.content {
	background-position: -608px -32px;
}

button em.icon.documentation {
	background-position: -624px -32px;
}

button em.icon.module {
	background-position: -640px -32px;
}

button em.icon.job {
	background-position: -656px -32px;
}

button em.icon.libraryItem {
	background-position: -672px -32px;
}

button em.icon.link {
	background-position: -688px -32px;
}

button em.icon.lock {
	background-position: -704px -32px;
}

button em.icon.personaeFolder {
	background-position: -720px -32px;
}

button em.icon.plfng {
	background-position: -736px -32px;
}

button em.icon.ploneGlossary {
	background-position: -752px -32px;
}

button em.icon.portlet {
	background-position: -768px -32px;
}

button em.icon.question {
	background-position: -784px -32px;
}

button em.icon.scenario {
	background-position: -800px -32px;
}

button em.icon.topic {
	background-position: -816px -32px;
}

button em.icon.projectGeneric {
	background-position: -832px -32px;
}

button em.icon.projectConceptDesign {
	background-position: -848px -32px;
}

button em.icon.projectApplicationDesign {
	background-position: -864px -32px;
}

button em.icon.action {
	background-position: -880px -32px;
}

button em.icon.media {
	background-position: -1005px -64px;
	background-color: transparent;
}

button em.icon.listView {
	background-position: -1021px -64px;
	background-color: transparent;
}

button em.icon.thumbnailView {
	background-position: -1037px -64px;
	background-color: transparent;
}

button em.icon.preview {
	background-position: -1151px -64px;
	background-color: transparent;
}

button em.icon.contentEdit {
	background-position: -1135px -64px;
	background-color: transparent;
}

/* @end */



/* @end */

/* @group Small icons */

.icon.organicer {
	background-position: 0 0;
}

.icon.blog {
	background-position: -16px 0;
}

.icon.prototype {
	background-position: -32px 0;
}

.icon.element {
	background-position: -48px 0;
}

.icon.component {
	background-position: -64px 0;
}

.icon.screen {
	background-position: -80px 0;
}

.icon.template {
	background-position: -96px 0;
}

.icon.persona {
	background-position: -112px 0;
}

.icon.project {
	background-position: -128px 0;
}

.icon.add {
	background-position: -144px 0;
}

.icon.priorityMinor {
	background-position: -160px 0;
}

.icon.priorityNormal {
	background-position: -176px 0;
}

.icon.priorityCritical {
	background-position: -192px 0;
	background-color: red;
}

.icon.adl {
	background-position: -208px 0;
}

.icon.richPage {
	background-position: -224px 0;
}

.icon.issueTracker {
	background-position: -240px 0;
}

.icon.simpleBlog {
	background-position: -256px 0;
}

.icon.file {
	background-position: -272px 0;
}

.icon.newPage {
	background-position: -288px 0;
}

.icon.cut {
	background-position: -304px 0;
}

.icon.copy {
	background-position: -320px 0;
}

.icon.paste {
	background-position: -336px 0;
}

.icon.permissions {
	background-position: -352px 0;
}

.icon.pageProperties {
	background-position: -368px 0;
}

.icon.twistyOpen {
	background-position: -384px 0;
}

.icon.twistyExpanded {
	background-position: -400px 0;
}

.icon.edit {
	background-position: -416px 0;
}

.icon.info {
	background-position: -432px 0;
	-webkit-border-radius: 8px;
	-moz-border-radius: 8px;
	border-radius: 8px;
}

.icon.issue {
	background-position: -448px 0;
}

.icon.zoom {
	background-position: -464px 0;
}

.icon.discussion {
	background-position: -480px 0;
	padding: 0 !important;
	margin: 0;
}

.icon.ency {
	background-position: -496px 0;
}

.icon.event {
	background-position: -512px 0;
}

.icon.faq {
	background-position: -528px 0;
}

.icon.favorite {
	background-position: -544px 0;
}

.icon.formulaDoc {
	background-position: -560px 0;
}

.icon.generate {
	background-position: -576px 0;
}

.icon.annotation {
	background-position: -592px 0;
}

.icon.content {
	background-position: -608px 0;
}

.icon.documentation {
	background-position: -624px 0;
}

.icon.module {
	background-position: -640px 0;
}

.icon.job {
	background-position: -656px 0;
}

.icon.libraryItem {
	background-position: -672px 0;
}

.icon.link {
	background-position: -688px 0;
}

.icon.lock {
	background-position: -704px 0;
}

.icon.personaeFolder {
	background-position: -720px 0;
}

.icon.plfng {
	background-position: -736px 0;
}

.icon.ploneGlossary {
	background-position: -752px 0;
}

.icon.portlet {
	background-position: -768px 0;
}

.icon.question {
	background-position: -784px 0;
}

.icon.scenario {
	background-position: -800px 0;
}

.icon.topic {
	background-position: -816px 0;
}

.icon.projectGeneric {
	background-position: -832px 0;
}

.icon.projectConceptDesign {
	background-position: -848px 0;
}

.icon.projectApplicationDesign {
	background-position: -864px 0;
}

.icon.action {
	background-position: -880px 0;
}

.icon.media {
	background-position: -1005px 0;
}

.icon.listView {
	background-position: -1021px 0;
}

.icon.thumbnailView {
	background-position: -1037px 0;
}

.icon.user {
	background-position: -1104px 0;
}

.icon.group {
	background-position: -1120px 0;
}

.icon.upload {
	background-position: -1215px 0;
}

.icon.button.upload {
	background-position: -1215px -64px;
}

.iconComment {
	width: 16px;
	height: 0;
	padding-top: 16px;
	overflow: hidden;
	background: gray url(icons.png) -1087px 0;
}

/* @end */



/* @end */

/* @group Workflow State */

#workflowState {
	position: fixed;
	left: -190px;
	bottom: 70px;
	list-style-type: none;
	display: block;
	background-color: rgba(255,255,255,0.95);
	padding: 12px 5px 12px 45px;
	-webkit-box-shadow: 0 2px 7px rgba(0,0,0,0.4);
	-moz-box-shadow: 0 2px 7px rgba(0,0,0,0.4);
	-o-box-shadow: 0 2px 7px rgba(0,0,0,0.4);
	box-shadow: 0 2px 7px rgba(0,0,0,0.4);
	-webkit-transition: all 0.5s;
	-moz-transition: all 0.5s;
	-o-transition: all 0.5s;
	transition: all 0.5s;
	display: block;
	width: 140px;
	border-right: 32px solid #cccece;
	z-index: 10;
}

#workflowState textarea {
	width: 135px;
	max-width: 142px;
	margin-bottom: 8px;
	margin-top: 10px;
	float: left;
	font-size: 10px;
	line-height: 15px;
	height: 45px;
}

#workflowState:hover {
	left: -5px;
}

#workflowState fieldset {
	display: block;
	margin: 0;
	clear: left;
}

#workflowState p.currentState {
	-webkit-transform: rotate(90deg);
	-moz-transform: rotate(90deg);
	-o-transform: rotate(90deg);
	transform: rotate(90deg);
	display: block;
	margin: -12px -72px 0 0;
	height: 25px;
	width: 110px;
	position: absolute;
	top: 50%;
	right: 0;
	padding: 0;
	text-align: center;
	width: 110px;
	letter-spacing: 1px;
	cursor: default;
	font-weight: bold;
	padding-right: 0;
	padding-top: 6px;
	padding-left: 0;
	writing-mode: tb-rl;
	font-size: 10px;
	color: white;
}

#workflowState .superImpose {
	position: absolute;
	left: 51px;
	width: 125px;
	max-width: 125px;
	bottom: 42px;
	height: 47px;
	max-height: 47px;
	font-size: 10px;
	line-height: 15px;
	color: gray;
}

.draft#workflowState {
	border-right-color: #ff8100;
}

.premature#workflowState {
	border-right-color: red;
}

.open#workflowState {
	border-right-color: #8229ff;
}

.proposal#workflowState {
	border-right-color: #ff77cf;
}

.active#workflowState li.currentState,
.closed#workflowState li.currentState,
.published#workflowState li.currentState {
	color: gray;
}

/* @end */

/* @group Forms */

form {
	margin: 0;
}

input,textarea {
	vertical-align: baseline;
	-webkit-transition: all 0.7s;
	-webkit-box-shadow: 0 0 0 rgba(0,0,0,0.4);
	-moz-box-shadow: 0 0 0 rgba(0,0,0,0.4);
	-0-box-shadow: 0 0 0 rgba(0,0,0,0.4);
	box-shadow: 0 0 0 rgba(0,0,0,0.4);
	outline: none;
	border: 1px solid #dedede;
	-webkit-background-size: auto 100%;
	-moz-background-size: auto 100%;
	background-size: auto 100%;
	font: 12px/20px Verdana, "Lucida Grande", Lucida, sans-serif;
	padding-left: 4px;
	display: inline-block;
	margin: 0;
	padding-top: 0;
	padding-bottom: 0;
	background: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#E8E8E8), to(#FFFFFF));
	background: -o-gradient(linear, 0% 0%, 0% 100%, from(#E8E8E8), to(#FFFFFF));
	background: -moz-linear-gradient(19% 75% 90deg,#FFFFFF, #E8E8E8);
	background: gradient(linear, 0% 0%, 0% 100%, from(#E8E8E8), to(#FFFFFF));
}

textarea {
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-o-box-sizing: border-box;
	box-sizing: border-box;
	margin-bottom: 1px;
}

input[type="text"],input[type="password"] {
	line-height: 17px;
}

input[type="text"],textarea,label.superImpose {
	cursor: text;
}

label.superImpose,
.concise .superImpose {
	color: #707070;
	display: block;
	margin-left: 7px;
	margin-top: 1px;
	padding: 0 0 1px;
	position: absolute;
	white-space: nowrap;
	border-style: none;
}

input:focus,
textarea:focus {
	background: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#FFFFFF), to(#FFFFFF));
	background: -o-gradient(linear, 0% 0%, 0% 100%, from(#FFFFFF), to(#FFFFFF));
	background:-moz-linear-gradient(19% 75% 90deg,#FFFFFF, #FFFFFF, #FFFFFF 100%);
	background: gradient(linear, 0% 0%, 0% 100%, from(#FFFFFF), to(#FFFFFF));
	-webkit-box-shadow: 0 0 10px rgba(0,0,0,0.3);
	-moz-box-shadow: 0 0 10px rgba(0,0,0,0.3);
	-o-box-shadow: 0 0 10px rgba(0,0,0,0.3);
	box-shadow: 0 0 10px rgba(0,0,0,0.3);
}

input[type="file"] {
	margin-left: 0px !important;
	background-image: none;
	background-color: transparent;
	border-style: none;
}

select {
	position: relative;
	top: -1px;
	margin-top: -1px;
	margin-bottom: -1px;
}

input[type="checkbox"],
input[type="radio"]{
	background: none!important;
	border: none;
}

form fieldset em.message {
	clear: left;
	float: left;
	margin-bottom: 10px;
	margin-top: 4px;
	padding: 3px 10px;
}

sup.required {
	color: silver;
}

/* @group Info panels */

.concise .infoPanel {
	margin-left: -16px;
	z-index: 1000;
	position: absolute;
	left: 100%;
	top: auto;
	margin-top: 3px;
}

.concise .infoPanel.open {
	margin-top: 27px;
}

.comprehensive .infoPanel {
	top: 0;
	margin-left: -16px;
}

.comprehensive .infoPanel.open,
.concise .infoPanel.open {
	z-index: 999;
}

fieldset.richInput .infoPanel {
	top: -1px;
}
/* @end */

/* @group Fieldsets */

fieldset {
	padding: 0 0 2px;
	border-style: none;
	margin: 0 0 20px;
}

fieldset p.legend,
fieldset p.legend {
	width: 95% !important;
	font-weight: bold;
	color: #3f3f3f;
	margin-bottom: 0;
	margin-top: 20px;
	letter-spacing: 1px;
	text-transform: uppercase;
}

fieldset p.legend:lang(el),
fieldset p.legend:lang(el-cy),
fieldset p.legend:lang(el-gr),
fieldset p.legend:lang(el),
fieldset p.legend:lang(el-cy),
fieldset p.legend:lang(el-gr) {
	text-transform: none !important;
}

/* @group Fieldset Concise */

fieldset.concise,
form.concise fieldset {
	width: 510px;
	clear: left;
	position: relative;
}

fieldset.concise p.legend,
form.concise fieldset p.legend,
fieldset.concise legend,
form.concise fieldset legend {
	width: auto;
	margin: 0;
	padding: 0;
	font-weight: bold;
	letter-spacing: 0;
	text-transform: none;
}

fieldset.concise label,
form.concise label {
	position: relative;
	float: left;
	padding-right: 65%;
	width: 35%;
	border-bottom: 1px solid #ebebeb;
	border-top: 1px solid #ebebeb;
	left: 0;
	margin-bottom: -1px;
	padding-top: 1px;
}

form.concise fieldset label *,
fieldset.concise label *,
form.concise fieldset label *,
fieldset.concise label * {
	position: relative;
	vertical-align: top;
	max-width: 320px;
	left: 100%;
	margin-right: -200%;
	margin-left: 0;
	float: left;
}

form.concise fieldset label sup.required,
fieldset.concise label sup.required,
form.concise fieldset label sup.required,
fieldset.concise label sup.required {
	float: none;
	display: inline;
	position: static;
	line-height: 20px;
}

form.concise fieldset label input[type=checkbox],
fieldset.concise label input[type=checkbox] {
	top: 3px;
}

form.concise fieldset label select {
	top: 1px;
}

.concise textarea:not(.pat-redactor) {
	width: 170%;
}

/* @end */

/* @group Fieldset Comprehensive */

.comprehensive,
.comprehensive fieldset,
.concise fieldset.comprehensive,
.compact fieldset.comprehensive {
	width: 65%;
	clear: left;
	border-bottom: 1px solid #ebebeb;
	border-style: none;
	margin: 0;
	margin-bottom: 10px;
	padding-left: 35%;
	padding-bottom: 0;
	position: relative;
	padding-top: 1px;
}

fieldset.comprehensive legend {
	position: absolute;
	left: 260px;
	font-weight: normal;
	font-style: normal;
}

fieldset.comprehensive label,
form.comprehensive fieldset label,
form.concise fieldset.comprehensive label,
form.compact fieldset.comprehensive label {
	display: block;
	margin: 0.5em 0;
	font-weight: normal;
	font-style: normal;
	position: static;
	border-style: none;
	width: auto;
	padding: 0;
	float: none;
}

.concise fieldset.comprehensive,
.condensed fieldset.comprehensive {
	border-bottom-style: none;
	margin: 0 0 -1px;
	padding-bottom: 0 !important;
	border-bottom: 1px solid #ebebeb;
	border-top: 1px solid #ebebeb;
	padding-top: 1px;
	height: auto;
}

fieldset.comprehensive label *,
form.comprehensive fieldset label *,
form.concise fieldset.comprehensive label *,
form.compact fieldset.comprehensive label * {
	position: static !important;
	margin: 0;
	float: none;
}

fieldset.comprehenisve input[type="radio"],
.concise fieldset.comprehensive input[type="radio"] {
	margin-top: 3px;
}

fieldset.comprehenisve input[type="checkbox"],
.concise fieldset.comprehensive input[type="checkbox"] {
	margin-top: 3px;
}

fieldset.comprehensive p.legend,
form.comprehensive fieldset p.legend,
fieldset.comprehensive p.legend,
form.comprehensive fieldset p.legend,
form.concise fieldset.comprehensive p.legend,
form.compact fieldset.comprehensive p.legend {
	width: 48% !important;
	display: inline;
	text-align: left;
	padding: 0;
	position: relative;
	float: left;
	font-weight: normal;
	font-style: normal;
	color: black;
	margin: 0 0 0 -54%;
	text-transform: none;
	letter-spacing: 0;
}

fieldset.comprehensive label a.floatAfter {
	float: right;
	margin-right: 22px;
}

/* @end */

/* @group Fieldset Condensed */

fieldset.condensed,
form.condensed fieldset {
	clear: left;
	border-style: none;
	margin: 0 0 20px;
}

fieldset.condensed label,
form.condensed fieldset label {
	clear: left;
	font-weight: normal;
	font-style: normal;
	display: inline-block;
	margin-bottom: 20px;
}

fieldset.condensed p.legend {
	width: auto;
	margin: 0;
	letter-spacing: 0;
	text-transform: none;
}

fieldset.condensed label input,
form.condensed fieldset label input,
fieldset.condensed label textarea {
	float: left;
	margin-top: 0;
	margin-bottom: 0;
}

fieldset.condensed fieldset p.legend {
	font-weight: normal;
	font-style: normal;
}

/* @end */

/* @end */

/* @group Form Components */

/* @group date-eu */

.date-eu {

}

.date-eu label {
	display: none;
}

.date-eu input.day {
	width: 21px;
}

.date-eu input.year {
	width: 38px;
}

/* @end */

/* @group Radio List */

.radioList {
	list-style-type: none !important;
	margin: 0;
	padding-bottom: 4px !important;
}

.radioList label {
	display: block;
	width: auto !important;
	padding-left: 18px !important;
}

.radioList label input {
	float: left;
	margin: 3px 5px 0 -18px !important;
}

.radioList label input[type="file"] {
	clear: both;
	padding-left: 0;
	margin: 5px 5px 0 0px !important;
}

.portlet .radioList label input {
	margin-top: 2px !important;
}

/* @end */

/* @group Checkbox List */

.checkboxList label input {
	margin: 4px 5px 0 0 !important;
}

/* @end */

/* @group Radio Row */

.radioRow {

}

.radioRow label,
label.radioRow {
	display: inline;
	width: auto !important;
	float: left;
	padding-right: 10px !important;
}

.radioRow input,
label.radioRow input {
	margin-top: 4px;
	margin-right: 5px;
	margin-bottom: 0;
	position: static !important;
}

/* @end */

/* @group Input Row */

ul.inputRow,
ol.inputRow {
	display: inline;
	margin-top: 0;
	padding-top: 0;
	margin-left: 0;
	padding-left: 0;
	list-style-type: none !important;
}

/* @end */

/* @group Input List */

ul.inputList,
ol.inputList,
ol.radioList,
ul.radioList,
ol.checkList,
ul.checkList {
	margin-top: 0;
	padding-top: 0;
	margin-left: 0;
	padding-left: 0;
	list-style-type: none !important;
}

ul.inputList li,
ol.radioList li,
ul.radioList li,
ol.checkList li,
ul.checkList li {
	margin-left: 0;
	padding-left: 0;
	display: block;
}

/* @end */

/* @group Check List */

.checkList {
	list-style-type: none !important;
	margin: 0;
	padding-bottom: 4px !important;
}

.checkList label {
	display: block;
	width: auto !important;
}

fieldset.checkList label input {
	float: left;
	position: static !important;
	margin: 4px 5px 0 0 !important;
}

.portlet .checkList input {
	margin-top: 3px;
}

/* @end */

/* @group Check Row */

ol.checkRow li,
ul.checkRow li,
ol.radioRow li,
ul.radioRow li {
	float: none;
	margin-left: 0;
	padding-left: 0;
	display: inline;
}

ol.checkRow li label,
ul.checkRow li label,
ol.radioRow li label,
ul.radioRow li label {
	display: inline;
}

/* @end */

/* @end */

/* @end */

/* @group Portlets */

#portlets {
	margin-right: 0;
	border-left: 1px solid white;
	margin-left: -1px;
	position: absolute !important;
	border-top: 1px solid white;
	z-index: 1;
	top: 172px;
	left: 840px;
	background-color: white;
	width: 260px;
	line-height: 18px;
}

#portlets p,#portlets ul,#portlets ol,#portlets table,#portlets dl {
	margin-bottom: 18px;
}

/* Static !important is voor de sortable bug */

.portlet a {
	text-decoration: none;
}

.portlet a:hover {
	text-decoration: underline;
}

.portlet ul {
	list-style-type: none;
	padding-left: 0;
}

.portlet ul li {
	margin-left: 0;
	padding-left: 4px;
}

.portlet ul ul li {
	padding-left: 0;
}

#portlets .portlet h3 {
	margin: -1px -10px 1px;
	padding: 10px;
	font-weight: normal;
	font-style: normal;
	font-size: 12px;
	background-color: #ebebeb;
	color: #787878;
	letter-spacing: 1px;
	cursor: move;
	border-bottom: 1px solid white;
	line-height: 13px;
}

#portlets .portlet h3 a {
	font-weight: bold;
	letter-spacing: 0;
}

#portlets .portlet h3 a sup {
	font-weight: normal;
	text-transform: capitalize;
}

#portlets .portlet h4 {
	letter-spacing: 1px;
}

#portlets .portlet h5 {
	letter-spacing: 1px;
	font-size: 10px;
	color: #515151;
	display: block;
	float: none;
}

#portlets .portlet {
	width: 260px;
	-webkit-transition: width 0.8s;
	position: relative;
	float: left;
	padding-left: 9px;
	margin-left: -7px;
}

#portlets .portlet .portletContent {
	margin-bottom: 20px;
	clear: left;
	margin-top: 10px;
	width: 260px;
	float: left;
}

#portlets .portlet.contextual .portletContent {
	margin-top: 0;
}

#portlets,
#portlets select {
	font-size: 10px;
	color: gray;
}

#portlets .field select,
#portlets .field select textarea {
	width: 100%;
}

#portlets input[type="radio"] {
	font-size: 12px;
	margin-top: 0;
}

#portlets input[type="checkbox"] {
	font-size: 12px;
	margin-right: 5px;
}

#portlets .concise label input[type="checkbox"] {
	top: 4px;
}

#portlets .comprehensive .question,
#portlets .comprehensive .legend,
#portlets .concise label {
	color: black;
	font-weight: bold;
	line-height: 15px;
	padding-top: 2px;
}

#portlets .concise .comprehensive label {
	line-height: inherit;
	font-weight: normal;
	font-style: normal;
	padding-top: 0;
}

#portlets fieldset.concise {
	width: 260px;
}

#portlets input,
#portlets textarea {
	max-width: 255px;
}

#portlets .concise label textarea {
	padding-left: 0;
	width: 150px;
}

#portlets fieldset.concise input[type="text"],
#portlets fieldset.concise input[type="password"],
#portlets fieldset.concise textarea,
#portlets fieldset.concise select {
	max-width: 150px;
	font-size: 10px;
	line-height: 13px;
	margin-top: -1px;
}

#portlets li a:hover {
	text-decoration: underline;
}

#portlets li a.icon.info {
	position: relative;
	top: 2px;
}

.collapsible{
	position: relative;
}

.collapsibleHeader{
	height: 20px;
	margin: 10px 0;
	padding-left: 18px;
}

.expandedNode,
.toggleNode{
	height:16px;
	position:absolute;
	right:9px;
	text-decoration:none !important;
	width:16px;
	cursor: pointer;
	line-height:42px;
	overflow: hidden;
	visibility: hidden;
	margin-top: 1px;
}

a.folderish .expandedNode{
	background-image: url(navtree-collapse.png);
}
a.folderish .toggleNode{
	background-image: url(navtree-expand.png);
}

a:hover .expandedNode,
a:hover .toggleNode{
	visibility: visible!important;
}

.showChildren .expandedNode{
	background-image: url(navtree-collapse.png)!important;
}

.hideChildren .expandedNode{
	background-image: url(navtree-expand.png)!important;
}

.nodeLoading .toggleNode{
	background: url(tinyspinner.gif) center center no-repeat;
	visibility: visible;
}

#portlets .buttonBar {
	width: auto;
	padding: 0 4px;
}

/* @group Members */

.portlet .members {
	margin: 0 0 -10px !important;
	width: 270px;
	float: none;
	overflow: hidden;
}

.portlet .members li {
	margin-left: 0;
	margin-bottom: 10px;
	height: 50px;
	width: 50px;
	margin-right: 2px;
	clear: none;
}

.portlet .members li a {
	margin: 0;
	width: 50px;
	height: 50px;
	padding: 0;
}

.portlet .members li a span {
	margin: 0 !important;
	width: 50px !important;
	height: 50px;
}

.portlet .members li img {
	margin: 0;
	width: 50px !important;
}



/* @end */

/* @group Footers */

#portlets .footer {
	text-align: right;
	margin: 0;
}

#portal-footer-signature {
  clear: both;
  text-align: center;
}

/* @end */

/* @group Contextual Portlet */

#portlets .portlet.contextual {
	margin-left: -15px;
	padding-left: 15px;
	background-color: white;
	border-left: 1px solid white;
}

#portlets .portlet.contextual h3 {
	background-color: transparent;
	background-image: none;
	border-top: 1px solid gray;
	border-right: 1px solid gray;
	color: black;
}

/* @end */

/* @end */

/* @group Buttons */

.button:disabled,
button:disabled,
button.disabled,
.button.disabled {
	opacity: 0.3;
}

.buttonBar {
	background-color: #ebebeb;
	width: 500px;
	padding: 5px;
	clear: left;
	margin-bottom: 20px;
	height: 25px;
}

.floatingPanel-modal .buttonBar,
.kupu-drawer .buttonBar {
	background-color: transparent;
	margin-top: 20px;
	margin-bottom: -10px;
	padding: 0;
}

.buttonBar fieldset.group {
	margin-left: 10px;
	margin-right: 1px;
	float: right;
	padding-left: 10px;
	border-left: 1px solid silver;
	padding-bottom: 0;
}

.buttonBar fieldset.group button.floatAfter {
	margin-left: 0;
}

.buttonBar fieldset.group button.floatAfter {
	margin-right: -1px;
}

button.floatAfter,
a.button.floatAfter {
	margin-left: 10px;
}

button.floatBefore,
a.button.floatBefore {
	float: left;
	margin-right: 10px;
}

a.button,
button,
.accordion .header,
input[type="submit"],
input[type="button"],
.accordion dt {
	font-size: 12px;
	padding: 4px 10px;
	margin: 0 5px 0 0;
	border: 1px solid #d5d5d5;
	color: #3f3f3f;
	text-shadow: 0px 1px 0px rgba(250, 250, 250, 1);
	background: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#FFFFFF), to(#C4C4C4));
	background: -o-gradient(linear, 0% 0%, 0% 100%, from(#FFFFFF), to(#C4C4C4));
	background: -moz-linear-gradient(19% 75% 90deg,#C4C4C4, #FFFFFF);
	background: gradient(linear, 0% 0%, 0% 100%, from(#FFFFFF), to(#C4C4C4));
	cursor: default;
	text-decoration: none;
	line-height: 16px;
}

.portlet p.buttonBar.top {
	position: absolute;
	top: 4px;
	right: -5px;
	width: auto;
	padding: 5px 0 0;
	background-color: transparent;
}

button::-moz-focus-inner {
	border: 0;
}

a.button.small,
button.small,
button.sublime.small:hover,
a.button.sublime.small:hover {
	font-size: 10px;
	padding: 2px 7px;
	border: 1px solid #d5d5d5;
	color: #3f3f3f;
	text-shadow: 0px 1px 0px rgba(250, 250, 250, 1);
	line-height: 20px;
	height: 25px;
	margin-right: 10px;
}

button:active,
.accordion .header:active,
button.small.sublime:active,
button.sublime:active,
input[type="submit"]:active,
input[type="button"]:active,
button.on,a.button:active {
	background: -webkit-gradient(linear, left top, left bottom, from(#silver), to(white), color-stop(1, #fff));
   box-shadow:inset 0 1px 10px rgba(0,0,0,0.5);
   -moz-box-shadow:inset 0 1px 10px rgba(0,0,0,0.5);
   -webkit-box-shadow:inset 0 1px 10px rgba(0,0,0,0.5);
}

/* Added top and bottom paddings to next selector for Firefox' crazy lineheight bugs */

a.button.micro,
button.micro,
button.sublime.small:hover,
a.button.sublime.small:hover,
.portlet p.buttonBar.top button {
	font-size: 10px;
	padding: 2px 7px;
	border: 1px solid #d5d5d5;
	color: #3f3f3f;
	text-shadow: 0px 1px 0px rgba(250, 250, 250, 1);
	line-height: 13px;
	margin-bottom: 2px;
	margin-top: 3px;
	margin-right: 0;
}

a.button.micro:active,
button.micro:active {
	background: -webkit-gradient(linear, left top, left bottom, from(#silver), to(white), color-stop(1, #fff));

}

button.small.back,
a.small.back {
	background: url(button-back.png) no-repeat 0 0;
	border-top-style: none;
	border-bottom-style: none;
	border-left-style: none;
	padding-top: 3px!important;
	padding-bottom: 0!important;
	padding-left: 13px!important;
	font-weight: bold;
	height: 22px!important;
}

button.small.back:active,
a.small.back:active
 {
	background: url(button-back.png) no-repeat 0 -48px !important;
}

.buttonBar hr,
li.functions hr {
	float: right;
	height: 10px;
	width: 21px;
	margin-right: 10px;
	clear: none !important;
	display: inline;
}

.buttonBar fieldset,
li.functions fieldset {
	float: right;
	margin: 0;
}

.buttonBar .gearbox {
	float: right;
	margin-left: 10px;
}

/* @group Sublime */

button.sublime,a.button.sublime {
	background-image: none;
	background-color: white;
	border-color: white;
}

button.sublime em.icon,
a.button.sublime em.icon{
	background-position-y: 0 !important;
}

button.sublime:active em.icon,
a.button.sublime:active em.icon{
	background-position-y: 0 !important;
}



/* @end */

/* @end */

/* @group Messages */

.message {
	padding: 8px;
	margin-bottom: 20px;
	-webkit-box-shadow: 0 2px 10px rgba(0,0,0,0.25);
	-moz-box-shadow: 0 2px 10px rgba(0,0,0,0.25);
	box-shadow: 0 2px 10px rgba(0,0,0,0.25);
	width: 490px;
}

.message *:last-child {
	margin-bottom: 0;
}

.message.notice {
	background-color: #fdfdc8;
	color: #6f5a44;
	border: 1px solid #d3d4a7;
	padding: 9px;
}

.message.success {
	background-color: #b4ff8e;
	color: #405f31;
}

.message.warning {
	background-color: #ff8100;
	color: white;
}

.message.warning * {
	color: white !important;
}

.message.error {
	background-color: red;
	color: white;
}

.message.error * {
	color: white !important;
}

/* @group Form messages */

.concise .message {
	width: 150%;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	-o-box-shadow: none;
	box-shadow: none;
	padding: 0;
}

.comprehensive .message {
	width: 81%;
}

.concise .message.warning {
	background-color: transparent;
	color: #ff8100;
}

/* @end */

/* @group Self healing messages */

#selfhealing-messages {
	position: fixed;
	top: 20px;
	left: 20px;
	z-index: 30000;
}

.message-selfHealing {
	width: 300px;
	margin-bottom: 20px;
}

.selfHealing {
	float: left;
	clear: left;
	width: 300px;
	padding: 20px;
	-webkit-box-shadow: 0 0 20px rgba(0,0,0,0.2);
	-moz-box-shadow: 0 0 20px rgba(0,0,0,0.2);

	box-shadow: 0 0 20px rgba(0,0,0,0.2);

	display: none;
}

#messageWrapper .selfHealing {
	display: block;
}

/* @end */



/* @end */

/* @group Small screen */

.medium {
	min-width: 0px;
	overflow-x: hidden;
}

.medium #content {
	border-right: 1px solid white;
}

.medium #globalNavigation,
.medium #doormat {
	width: 100%;
}

.medium #portlets {
	position: absolute;
	-webkit-box-shadow: 0 0 0 rgba(0,0,0,0);
	-moz-box-shadow: 0 0 25px rgba(0,0,0,0);
	box-shadow: 0 0 25px silver;
	padding-right: 0;
	margin: 0;
	padding-left: 70px;
	overflow: hidden;
	border-top: 1px solid silver;
	border-bottom: 1px solid silver;
	border-left: 1px solid silver;
	width: 0;
	right: 0;
	left: auto;
	background: rgba(255,255,255,0.95);
	z-index: 1000;
}

.medium #portlets:hover {
	width: 280px;
	-webkit-box-shadow: 0 0 25px rgba(0,0,0,0.4);
	-moz-box-shadow: 0 0 25px rgba(0,0,0,0.4);
	box-shadow: 0 0 25px rgba(0,0,0,0.4);
	-webkit-transition: -webkit-box-shadow .4s;
	-moz-transition: -moz-box-shadow .4s;
	transition: box-shadow .4s;
	-webkit-transition: width 1s;
	-moz-transition: width 1s;
	transition: width .7s;
}

.medium #portlets .portlet {
	/*opacity: 0;*/
	visibility: hidden;
}

.medium #portlets:hover .portlet {
	/*opacity: 1;*/
	visibility: visible;
}

.medium #portlets:before {
	content: "▾";
	width: 40px;
	height: 40px;
	float: left;
	margin-left: -61px;
	display: block;
	margin-bottom: -70px;
	color: silver;
	font-size: 44px;
	margin-top: 25px;
	-webkit-transform: rotate(90deg);
	-moz-transform: rotate(90deg);
	transform: rotate(90deg);
	-webkit-transition: all 0.8s;
}

.medium #portlets:hover:before {
	-webkit-transform: rotate(-450deg);
	-moz-transform: rotate(-90deg);
	transform: rotate(-90deg);
	margin-left: -51px;
	margin-top: 13px;
}

.medium.win #portlets:before {
	content: "";
	background: url(portletHandle.gif) 0 0 no-repeat;
	-webkit-transform: none !important;
	-moz-transform: none !important;
	transform: none !important;
	-webkit-transition: none !important;
}
.medium.win #portlets:hover:before {
	background: url(portletHandle.gif) top right no-repeat;
}


.medium #portlets h3 {
	border-style: none !important;
}

.medium ol.navigationBreadcrumbs li {
	left: 0;
}

/* @end */

/* @group Info Panel*/

dfn.infoPanel {
	background: url(infoPanel.png) no-repeat 0 -31px;
	color: gray;
	font-size: 11px;
	padding: 16px 0 0;
	width: 16px;
	height: 0;
	position: absolute;
	text-decoration: none;
	border-style: none;
	display: inline-block;
	overflow: hidden;
	font-weight: normal;
	font-style: normal;
	-webkit-user-select: none;
	-moz-user-select: none;
	-o-user-select: none;
	user-select: none;
	z-index: 3;
	-webkit-transform-origin: 8px -23px;
	-moz-transform-origin: 8px -23px;
	-o-transform-origin: 8px -23px;
	transform-origin: 8px -23px;
}

label dfn.infoPanel,
legend dfn.infoPanel {
	margin-top: 2px;
}

dfn.infoPanel.open {
	background: url(infoPanel.png) no-repeat -16px bottom;
	padding: 0 10px 35px 42px;
	width: 205px;
	height: auto;
	margin-top: 26px;
	overflow: visible;
	-webkit-animation: pop 0.3s ease-in-out;
	-moz-animation: pop 0.3s ease-in-out;
	animation: pop 0.3s ease-in-out;
	-o-animation: pop 0.3s ease-in-out;
	z-index: 1001;
}

dfn.infoPanel.open span.title {
	content: ""attr(title)"";
	font-size: 12px;
	font-weight:bold;
	display: block;
	background: url(infoPanel.png) -16px top;
	padding: 32px 10px 3px 61px;
	margin: -55px -35px 0 -42px;
}

dfn.infoPanel.bottom {
	top: 22px;
}
/* @end */

/* @group Separators */

hr.clear {
	height: 20px;
	margin: 0 10px;
	padding: 0 !important;
	list-style-image: none;
	clear: both;
	border-style: none;
}



/* @end */
